import * as zod from 'zod';

declare const FLOAT_ARRAY_BITS: readonly [32, 64];
type FloatArrayBit = (typeof FLOAT_ARRAY_BITS)[number];
declare const FLOAT32_ARRAY_SCHEMA: zod.ZodType<Float32Array, zod.ZodTypeDef, Float32Array>;
declare const FLOAT64_ARRAY_SCHEMA: zod.ZodType<Float64Array, zod.ZodTypeDef, Float64Array>;
declare const FLOAT_ARRAY_SCHEMAS: {
    readonly 32: zod.ZodType<Float32Array, zod.ZodTypeDef, Float32Array>;
    readonly 64: zod.ZodType<Float64Array, zod.ZodTypeDef, Float64Array>;
};
type FloatArrays = {
    32: Float32Array;
    64: Float64Array;
};
type FloatArray<Bit extends FloatArrayBit> = FloatArrays[Bit];
interface FloatArrayOptions<Bit extends FloatArrayBit> {
    bit: Bit;
}
declare function validateFloatArray<Bit extends FloatArrayBit>(value: unknown, options: FloatArrayOptions<Bit>): asserts value is FloatArray<Bit>;
declare function isFloatArray<Bit extends FloatArrayBit>(value: unknown, options: FloatArrayOptions<Bit>): value is FloatArray<Bit>;

export { FLOAT32_ARRAY_SCHEMA, FLOAT64_ARRAY_SCHEMA, FLOAT_ARRAY_BITS, FLOAT_ARRAY_SCHEMAS, FloatArray, FloatArrayBit, FloatArrayOptions, FloatArrays, isFloatArray, validateFloatArray };
